def show_primes(x, y):
    for num in range(x, y + 1):
        if num > 1: # all numbers greater than 1
            for i in range(2, num): # Don't forget 2; it's a prime number too!
                if (num % i) == 0: # if number is divisble by i...
                    break # Stop program
            else: # If not...
                print(num) # Display the number


def computeLCM(x, y):
    if x > y: # Choose the greater number
        greater = x
    else:
        greater = y
    
    while (True): # Loopin' time!
        if ((greater % x == 0) and (greater % y == 0)):
            lcm = greater
            break
        greater += 1
    return lcm


def add(x, y):
    return x + y # addition

def subtract(x, y):
    return x - y # subtraction

def multiply(x, y):
    return x * y # multiplcation

def divide(x, y): # Careful here...
    try: # Use the try block to avoid error
        return x / y
    except ZeroDivisionError: # Ya can't divide by zero!!
        return 'Undefined' # Let's just say a message 'Undefined'

def power(x, y):
    return x ** y # exponent